#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'backgroundselector.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BACKGROUNDSELECTOR_H
#define UI_BACKGROUNDSELECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_KBounceBackgroundSelector
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *kcfg_UseRandomBackgroundPictures;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout;
    QLabel *backgoundPicturePathLabel;
    KUrlRequester *kurlrequester;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    QSpacerItem *horizontalSpacer_2;
    QLabel *backgroundPicturePreview;
    QSpacerItem *verticalSpacer;
    KLineEdit *kcfg_BackgroundPicturePath;

    void setupUi(QWidget *KBounceBackgroundSelector)
    {
        if (KBounceBackgroundSelector->objectName().isEmpty())
            KBounceBackgroundSelector->setObjectName(QStringLiteral("KBounceBackgroundSelector"));
        KBounceBackgroundSelector->resize(600, 270);
        gridLayout = new QGridLayout(KBounceBackgroundSelector);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        kcfg_UseRandomBackgroundPictures = new QCheckBox(KBounceBackgroundSelector);
        kcfg_UseRandomBackgroundPictures->setObjectName(QStringLiteral("kcfg_UseRandomBackgroundPictures"));

        horizontalLayout_2->addWidget(kcfg_UseRandomBackgroundPictures);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        backgoundPicturePathLabel = new QLabel(KBounceBackgroundSelector);
        backgoundPicturePathLabel->setObjectName(QStringLiteral("backgoundPicturePathLabel"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(backgoundPicturePathLabel->sizePolicy().hasHeightForWidth());
        backgoundPicturePathLabel->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(backgoundPicturePathLabel);

        kurlrequester = new KUrlRequester(KBounceBackgroundSelector);
        kurlrequester->setObjectName(QStringLiteral("kurlrequester"));
        sizePolicy.setHeightForWidth(kurlrequester->sizePolicy().hasHeightForWidth());
        kurlrequester->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(kurlrequester);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        label = new QLabel(KBounceBackgroundSelector);
        label->setObjectName(QStringLiteral("label"));

        horizontalLayout_3->addWidget(label);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        backgroundPicturePreview = new QLabel(KBounceBackgroundSelector);
        backgroundPicturePreview->setObjectName(QStringLiteral("backgroundPicturePreview"));
        backgroundPicturePreview->setMinimumSize(QSize(160, 120));
        backgroundPicturePreview->setAlignment(Qt::AlignCenter);

        horizontalLayout_3->addWidget(backgroundPicturePreview);


        verticalLayout->addLayout(horizontalLayout_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        kcfg_BackgroundPicturePath = new KLineEdit(KBounceBackgroundSelector);
        kcfg_BackgroundPicturePath->setObjectName(QStringLiteral("kcfg_BackgroundPicturePath"));

        verticalLayout->addWidget(kcfg_BackgroundPicturePath);


        gridLayout->addLayout(verticalLayout, 0, 0, 1, 1);


        retranslateUi(KBounceBackgroundSelector);

        QMetaObject::connectSlotsByName(KBounceBackgroundSelector);
    } // setupUi

    void retranslateUi(QWidget *KBounceBackgroundSelector)
    {
        KBounceBackgroundSelector->setWindowTitle(tr2i18n("kbouncebackgroundselector", 0));
        kcfg_UseRandomBackgroundPictures->setText(tr2i18n("Enable random pictures as background", 0));
        backgoundPicturePathLabel->setText(tr2i18n("Choose picture path:", 0));
        label->setText(tr2i18n("Preview", 0));
    } // retranslateUi

};

namespace Ui {
    class KBounceBackgroundSelector: public Ui_KBounceBackgroundSelector {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BACKGROUNDSELECTOR_H

