/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kbounce-17.04.3/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KBounceMainWindow_t {
    QByteArrayData data[25];
    char stringdata0[277];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KBounceMainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KBounceMainWindow_t qt_meta_stringdata_KBounceMainWindow = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KBounceMainWindow"
QT_MOC_LITERAL(1, 18, 7), // "newGame"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 9), // "pauseGame"
QT_MOC_LITERAL(4, 37, 9), // "closeGame"
QT_MOC_LITERAL(5, 47, 11), // "gameOverNow"
QT_MOC_LITERAL(6, 59, 17), // "configureSettings"
QT_MOC_LITERAL(7, 77, 12), // "readSettings"
QT_MOC_LITERAL(8, 90, 15), // "settingsChanged"
QT_MOC_LITERAL(9, 106, 9), // "setSounds"
QT_MOC_LITERAL(10, 116, 3), // "val"
QT_MOC_LITERAL(11, 120, 13), // "showHighscore"
QT_MOC_LITERAL(12, 134, 12), // "displayLevel"
QT_MOC_LITERAL(13, 147, 5), // "level"
QT_MOC_LITERAL(14, 153, 12), // "displayScore"
QT_MOC_LITERAL(15, 166, 5), // "score"
QT_MOC_LITERAL(16, 172, 13), // "displayFilled"
QT_MOC_LITERAL(17, 186, 6), // "filled"
QT_MOC_LITERAL(18, 193, 12), // "displayLives"
QT_MOC_LITERAL(19, 206, 5), // "lives"
QT_MOC_LITERAL(20, 212, 11), // "displayTime"
QT_MOC_LITERAL(21, 224, 4), // "time"
QT_MOC_LITERAL(22, 229, 16), // "gameStateChanged"
QT_MOC_LITERAL(23, 246, 24), // "KBounceGameWidget::State"
QT_MOC_LITERAL(24, 271, 5) // "state"

    },
    "KBounceMainWindow\0newGame\0\0pauseGame\0"
    "closeGame\0gameOverNow\0configureSettings\0"
    "readSettings\0settingsChanged\0setSounds\0"
    "val\0showHighscore\0displayLevel\0level\0"
    "displayScore\0score\0displayFilled\0"
    "filled\0displayLives\0lives\0displayTime\0"
    "time\0gameStateChanged\0KBounceGameWidget::State\0"
    "state"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KBounceMainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x09 /* Protected */,
       3,    0,   90,    2, 0x09 /* Protected */,
       4,    0,   91,    2, 0x09 /* Protected */,
       5,    0,   92,    2, 0x09 /* Protected */,
       6,    0,   93,    2, 0x09 /* Protected */,
       7,    0,   94,    2, 0x09 /* Protected */,
       8,    0,   95,    2, 0x09 /* Protected */,
       9,    1,   96,    2, 0x09 /* Protected */,
      11,    0,   99,    2, 0x09 /* Protected */,
      12,    1,  100,    2, 0x09 /* Protected */,
      14,    1,  103,    2, 0x09 /* Protected */,
      16,    1,  106,    2, 0x09 /* Protected */,
      18,    1,  109,    2, 0x09 /* Protected */,
      20,    1,  112,    2, 0x09 /* Protected */,
      22,    1,  115,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, 0x80000000 | 23,   24,

       0        // eod
};

void KBounceMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KBounceMainWindow *_t = static_cast<KBounceMainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newGame(); break;
        case 1: _t->pauseGame(); break;
        case 2: _t->closeGame(); break;
        case 3: _t->gameOverNow(); break;
        case 4: _t->configureSettings(); break;
        case 5: _t->readSettings(); break;
        case 6: _t->settingsChanged(); break;
        case 7: _t->setSounds((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->showHighscore(); break;
        case 9: _t->displayLevel((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->displayScore((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->displayFilled((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->displayLives((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->displayTime((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->gameStateChanged((*reinterpret_cast< KBounceGameWidget::State(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KBounceMainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KBounceMainWindow.data,
      qt_meta_data_KBounceMainWindow,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KBounceMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KBounceMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KBounceMainWindow.stringdata0))
        return static_cast<void*>(const_cast< KBounceMainWindow*>(this));
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KBounceMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
